@@ -1,18 +1,16 @@
 # coding: utf-8
 import uuid
 import weakref
+from django.utils.deprecation import MiddlewareMixin
 
-try:
-    from m3.core.middleware import get_thread_data
-except ImportError:
-    from m3_legacy.middleware import get_thread_data
+from m3_legacy.middleware import get_thread_data
 
 __author__ = 'Andrey Torsunov'
 __contact__ = 'torsunov@bars-open.com'
 __docformat__ = 'restructuredtext'
 
 
-class RequestTokenMiddleware(object):
+class RequestTokenMiddleware(MiddlewareMixin):
     u""" Middleware создающее токен для текущего запроса.
 
     Токен в последующем устаналвивается во все возникающие события
@@ -22,10 +20,10 @@ class RequestTokenMiddleware(object):
     """
     def process_request(self, request):
         _thread_local = get_thread_data()
-        _thread_local.request_token = unicode(uuid.uuid4())
+        _thread_local.request_token = str(uuid.uuid4())
 
 
-class CaptureRequestMiddleware(object):
+class CaptureRequestMiddleware(MiddlewareMixin):
     u""" Middleware сохраняющее текущий request.
 
     В последующем request используется для получения ряда параметров
